<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
#
# This file is part of Magix CMS.
# Magix CMS, a CMS optimized for SEO
# Copyright (C) 2010 - 2012  Gerits Aurelien <aurelien@magix-cms.com>
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# -- END LICENSE BLOCK -----------------------------------
/**
 * MAGIX CMS
 * @category   Controller 
 * @package    backend
 * @copyright  MAGIX CMS Copyright (c) 2011 Gerits Aurelien, 
 * http://www.magix-cms.com, http://www.magix-cjquery.com
 * @license    Dual licensed under the MIT or GPL Version 3 licenses.
 * @version    1.1
 * @author Gérits Aurélien <aurelien@magix-cms.com> <aurelien@magix-dev.be>
 * @name templates
 *
 */
class backend_controller_template{
	/**
	 * @access public
	 * Affiche le template
	 * @param string|object $template
	 * @param mixed $cache_id
	 * @param mixed $compile_id
	 * @param object $parent
	 */
	public static function display($template = null, $cache_id = null, $compile_id = null, $parent = null){
		return backend_config_smarty::getInstance()->display($template, $cache_id, $compile_id, $parent);
	}
	/**
	 * @access public
	 * Retourne le template
	 * @param string|object $template
	 * @param mixed $cache_id
	 * @param mixed $compile_id
	 * @param object $parent
	 * @param bool   $display           true: display, false: fetch
     * @param bool   $merge_tpl_vars    if true parent template variables merged in to local scope
     * @param bool   $no_output_filter  if true do not run output filter
     * @return string rendered template output
	 */
	public static function fetch($template = null, $cache_id = null, $compile_id = null, $parent = null, $display = false, $merge_tpl_vars = true, $no_output_filter = false){
		return backend_config_smarty::getInstance()->fetch($template, $cache_id, $compile_id, $parent, $display, $merge_tpl_vars, $no_output_filter);
	}
	/**
	 * Test si le cache est valide
	 * @param string|object $template
	 * @param mixed $cache_id
	 * @param mixed $compile_id
	 * @param object $parent
	 */
	public function isCached($template = null, $cache_id = null, $compile_id = null, $parent = null){
		return backend_config_smarty::getInstance()->isCached($template, $cache_id, $compile_id, $parent);
	}
	/**
	 * @access public
	 * Assign les variables dans les fichiers phtml
	 * @param void $tpl_var
	 * @param string $value
	 * @param bool $nocache
	 */
	public static function assign($tpl_var, $value = null, $nocache = false){
		if (is_array($tpl_var)){
			return backend_config_smarty::getInstance()->assign($tpl_var);
		}else{
			if($tpl_var){
				return backend_config_smarty::getInstance()->assign($tpl_var,$value,$nocache);
			}else{
				throw new Exception('Unable to assign a variable in template');
			}
		}
	}
	/**
	 * Charge les variables du fichier de configuration dans le site
	 * @param string $varname
	 */
	public static function getConfigVars($varname = null, $search_parents = true){
		return backend_config_smarty::getInstance()->getConfigVars($varname, $search_parents);
	}
}